==> haskell-servant-server-0.13.0.1-81-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.13.0.1
id: servant-server-0.13.0.1-CYo4IFgb6aqHyp2RXM9GfV
key: servant-server-0.13.0.1-CYo4IFgb6aqHyp2RXM9GfV
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 9fafefe76117c0f6f44ab16b61c320cb
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Internal Servant.Server.Internal.BasicAuth
    Servant.Server.Internal.Context Servant.Server.Internal.Handler
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServantErr Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/servant-server-0.13.0.1
hs-libraries: HSservant-server-0.13.0.1-CYo4IFgb6aqHyp2RXM9GfV
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 mtl-2.2.2
    text-1.2.3.0 transformers-0.5.5.0 filepath-1.4.2
    servant-0.13.0.1-9gYB9mbjda5JptwuFxXvYV
    aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc
    http-api-data-0.3.8.1-4hvgddH9V2mD84Z60Dv55C
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    monad-control-1.0.2.3-FfEOTMHoA2lIa1PKK0mtSB
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-base-0.4.5.2-6pRCll7YHiMAUH1nyaFDMy
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    wai-3.2.1.2-5X5AWGcLTJMBYHkaS1XJdn
    wai-app-static-3.1.6.2-mfJGdwG3cj81sdruDJTU0
    warp-3.2.25-AtjjBKlHJ72D6m2HvH6vr5
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             servant-0.13.0.1-9gYB9mbjda5JptwuFxXvYV=e1e609380365a14dff27edcf456531d8
             aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc=7e2a2010d6645bddac83e90b3cee8839
             http-api-data-0.3.8.1-4hvgddH9V2mD84Z60Dv55C=d9b64a626ce9407059666ac7a9872cd0
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB=302ec39836eeed635681d48972d58b60
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             monad-control-1.0.2.3-FfEOTMHoA2lIa1PKK0mtSB=96aa252ac60feebdbd0ad048336933d6
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=7baf46c0fb04e29c804c22c4ec2f96ad
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=14adf804eb2ee22bef25db71be916c66
             resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA=dcbdc81671b5884f063aea7a644e0575
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-base-0.4.5.2-6pRCll7YHiMAUH1nyaFDMy=2dceefd5edb84c5c6b1313f05ee22788
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             wai-3.2.1.2-5X5AWGcLTJMBYHkaS1XJdn=e1fd23653e3ca2821004ffc56c811100
             wai-app-static-3.1.6.2-mfJGdwG3cj81sdruDJTU0=b0469e64ff9da85d3563810940646bad
             warp-3.2.25-AtjjBKlHJ72D6m2HvH6vr5=1fdd9941b9a01893e2502d1309d70240
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=17353ed56fb5c760af7bb1df1e6d2f4c
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.13.0.1-82-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.13.0.1
id: servant-server-0.13.0.1-KMj1HywSOLRGaC8LmiRKCf
key: servant-server-0.13.0.1-KMj1HywSOLRGaC8LmiRKCf
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: bc1a51773adaab5b3a4cab20d5ee66f7
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Internal Servant.Server.Internal.BasicAuth
    Servant.Server.Internal.Context Servant.Server.Internal.Handler
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServantErr Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/servant-server-0.13.0.1
hs-libraries: HSservant-server-0.13.0.1-KMj1HywSOLRGaC8LmiRKCf
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 mtl-2.2.2
    text-1.2.3.0 transformers-0.5.5.0 filepath-1.4.2
    servant-0.13.0.1-EZ7WK8vh9h5EQQ4y4V51BL
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    http-api-data-0.3.8.1-HsmKi4q9sry407CCb10xd2
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u
    wai-app-static-3.1.6.2-GNd3ooL8PWy45pQpjO91bq
    warp-3.2.25-2PFmMejA0Xi8hKj936POP0
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             servant-0.13.0.1-EZ7WK8vh9h5EQQ4y4V51BL=8b1bdfb5ef423c970fbca44faaf73c14
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             http-api-data-0.3.8.1-HsmKi4q9sry407CCb10xd2=b176cb3071cad242a7d16935dd083e98
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb=976aaa70f9b7212c24b31f28f22b380a
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX=ccfd06c57089143c2e021ca11cc4fff5
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=7baf46c0fb04e29c804c22c4ec2f96ad
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=14adf804eb2ee22bef25db71be916c66
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u=d9fba6511abb80273dc6e619fc5c09ff
             wai-app-static-3.1.6.2-GNd3ooL8PWy45pQpjO91bq=2d247dc77b25897a51e5c62905739cc3
             warp-3.2.25-2PFmMejA0Xi8hKj936POP0=1a41b1a2d80e17e877c0498974828fd0
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=17353ed56fb5c760af7bb1df1e6d2f4c
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
